Learn R Programming

toscca (version 0.1.0)

toscca.core: Sparse Canonical Correlation Analysis. Computation of CC via NIPALS with soft thresholding.

Description

Sparse Canonical Correlation Analysis. Computation of CC via NIPALS with soft thresholding.

Usage

toscca.core(
  alphaInit,
  A,
  B,
  nonzero_a,
  nonzero_b,
  iter = 20,
  tol = 10^(-6),
  silent = FALSE
)

Value

a list with the following elements:

Arguments

alphaInit

Character. Type initialisation for $$\mathbf{\alpha}$$.

A, B

Data matrices.

nonzero_a, nonzero_b

Numeric. Scalar or vector over the number of nonzeroes allowed for a correlation estimate.

iter

Numeric. Maximum number of iterations. Default is 20.

tol

Numeric. Tolerance threshold. Default is 10^6.

silent

Logical. If FALSE, a progress bar will appear on the console. Default is FALSE.