Performs matrix residualisation over estimated canonical vectors. There are three types: basic (subtracts scaled estimated latent variable from data), null (uses the null space of the estimated canonical vector to construct a new matrix) and LV (uses SVD to residualise).
residualisation(
mat,
vec,
spaceMat = NULL,
type = c("LV", "null", "basic"),
na.allow = TRUE
)Matrix.
An nxp matrix.
A vector of dimensions nxk.
Only for "null" type residualisation. Default is NULL.
Character. It can be LV, null or basic depending on which type of residualisation will be performed.
Logical. If TRUE, NAs will be allowed.