Sparse Canonical Correlation Analysis. Computation of CC via NIPALS with soft thresholding.
toscca.core(
alphaInit,
A,
B,
nonzero_a,
nonzero_b,
iter = 20,
tol = 10^(-6),
silent = FALSE
)a list with the following elements:
Character. Type initialisation for $$\mathbf{\alpha}$$.
Data matrices.
Numeric. Scalar or vector over the number of nonzeroes allowed for a correlation estimate.
Numeric. Maximum number of iterations. Default is 20.
Numeric. Tolerance threshold. Default is 10^6.
Logical. If FALSE, a progress bar will appear on the console. Default is FALSE.